==> ejc-zjkjcost-api-3.0.0-20220629.013418-19-sources.jar: com/ejianc/business/zjkjcost/finish/vo/EstimateVO.java <==
package com.ejianc.business.zjkjcost.finish.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModelProperty;


/**
 * 竣工考核-履行情况考评-主表
 * 
 * @author generator
 * 
 */
public class EstimateVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Long applyId; // 申报主表id
    private String applyCode; // 申报主表code
    private Long contractId; // 合同主键
    private String contractName; // 合同名称
    private String contractCode; // 合同code
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String projectCode; // 项目code
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long departmentId; // 经办部门
    private String departmentName; // 经办部门名称
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private String orgCode; // 组织code
    private String parentOrgName; // 父级组织名称
    private String parentOrgCode; // 父级组织编码
    private Long parentOrgId; // 父级组织
    private String conditionBuild; // 施工目标完成情况
    private String conditionTechnology; // 技术目标完成情况
    private String conditionQuality; // 质量目标完成情况
    private String conditionCi; // CI等目标完成情况
    private String conditionSettle; // 结算目标完成情况
    private String conditionCapital; // 资金目标完成情况
    private String conditionSafe; // 安全目标完成情况
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @ApiModelProperty("单据状态（审批必须字段）")
    private String billStateName;

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getConditionSafe() {
        return conditionSafe;
    }

    public void setConditionSafe(String conditionSafe) {
        this.conditionSafe = conditionSafe;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode = "zjkj-finish-refApplyData")
    public Long getApplyId() {
        return applyId;
    }
    @ReferDeserialTransfer
    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public String getApplyCode() {
        return applyCode;
    }

    public void setApplyCode(String applyCode) {
        this.applyCode = applyCode;
    }

    /**
     * 合同主键
     */
    @ReferSerialTransfer(referCode = "ejc-zjkj-incontract")
    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getConditionBuild() {
        return conditionBuild;
    }

    public void setConditionBuild(String conditionBuild) {
        this.conditionBuild = conditionBuild;
    }
    public String getConditionTechnology() {
        return conditionTechnology;
    }

    public void setConditionTechnology(String conditionTechnology) {
        this.conditionTechnology = conditionTechnology;
    }
    public String getConditionQuality() {
        return conditionQuality;
    }

    public void setConditionQuality(String conditionQuality) {
        this.conditionQuality = conditionQuality;
    }
    public String getConditionCi() {
        return conditionCi;
    }

    public void setConditionCi(String conditionCi) {
        this.conditionCi = conditionCi;
    }
    public String getConditionSettle() {
        return conditionSettle;
    }

    public void setConditionSettle(String conditionSettle) {
        this.conditionSettle = conditionSettle;
    }
    public String getConditionCapital() {
        return conditionCapital;
    }

    public void setConditionCapital(String conditionCapital) {
        this.conditionCapital = conditionCapital;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
}

==> ejc-zjkjcost-api-3.0.0-20221019.075109-57-sources.jar: com/ejianc/business/zjkjcost/finish/vo/EstimateVO.java <==
package com.ejianc.business.zjkjcost.finish.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModelProperty;


/**
 * 竣工考核-履行情况考评-主表
 * 
 * @author generator
 * 
 */
public class EstimateVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Long applyId; // 申报主表id
    private String applyCode; // 申报主表code
    private Long contractId; // 合同主键
    private String contractName; // 合同名称
    private String contractCode; // 合同code
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String projectCode; // 项目code
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long departmentId; // 经办部门
    private String departmentName; // 经办部门名称
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private String orgCode; // 组织code
    private String parentOrgName; // 父级组织名称
    private String parentOrgCode; // 父级组织编码
    private Long parentOrgId; // 父级组织
    private String conditionBuild; // 施工目标完成情况
    private String conditionTechnology; // 技术目标完成情况
    private String conditionQuality; // 质量目标完成情况
    private String conditionCi; // CI等目标完成情况
    private String conditionSettle; // 结算目标完成情况
    private String conditionCapital; // 资金目标完成情况
    private String conditionSafe; // 安全目标完成情况
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @ApiModelProperty("单据状态（审批必须字段）")
    private String billStateName;
    @ApiModelProperty("工程款是否全部收回 1-是,2-否")
    private Integer refundFlag;

    public Integer getRefundFlag() {
        return refundFlag;
    }

    public void setRefundFlag(Integer refundFlag) {
        this.refundFlag = refundFlag;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getConditionSafe() {
        return conditionSafe;
    }

    public void setConditionSafe(String conditionSafe) {
        this.conditionSafe = conditionSafe;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode = "zjkj-finish-refApplyData")
    public Long getApplyId() {
        return applyId;
    }
    @ReferDeserialTransfer
    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public String getApplyCode() {
        return applyCode;
    }

    public void setApplyCode(String applyCode) {
        this.applyCode = applyCode;
    }

    /**
     * 合同主键
     */
    @ReferSerialTransfer(referCode = "ejc-zjkj-incontract")
    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getConditionBuild() {
        return conditionBuild;
    }

    public void setConditionBuild(String conditionBuild) {
        this.conditionBuild = conditionBuild;
    }
    public String getConditionTechnology() {
        return conditionTechnology;
    }

    public void setConditionTechnology(String conditionTechnology) {
        this.conditionTechnology = conditionTechnology;
    }
    public String getConditionQuality() {
        return conditionQuality;
    }

    public void setConditionQuality(String conditionQuality) {
        this.conditionQuality = conditionQuality;
    }
    public String getConditionCi() {
        return conditionCi;
    }

    public void setConditionCi(String conditionCi) {
        this.conditionCi = conditionCi;
    }
    public String getConditionSettle() {
        return conditionSettle;
    }

    public void setConditionSettle(String conditionSettle) {
        this.conditionSettle = conditionSettle;
    }
    public String getConditionCapital() {
        return conditionCapital;
    }

    public void setConditionCapital(String conditionCapital) {
        this.conditionCapital = conditionCapital;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
}
